@@ -763,12 +763,16 @@ class xasyMainWin:
     self.canQuit()
 
   def editUndoCmd(self):
+    if not self.editor == None:
+      return
     if(not self.testOrAcquireLock()):
       return
     self.undoOperation()
     self.releaseLock()
 
   def editRedoCmd(self):
+    if not self.editor == None:
+      return
     if(not self.testOrAcquireLock()):
       return
     self.redoOperation()
@@ -1334,8 +1338,8 @@ class xasyMainWin:
         self.bindItemEvents(theItem)
         self.addItemToFile(theItem)
         self.undoRedoStack.add(addLabelAction(self,theItem))
-        self.updateSelectedButton(self.toolSelectButton)
-        self.releaseLock()
+      self.releaseLock()
+      self.updateSelectedButton(self.toolSelectButton)
     elif self.selectedButton in [self.toolDrawLinesButton,self.toolDrawBeziButton,self.toolDrawPolyButton,self.toolDrawShapeButton,self.toolFillPolyButton,self.toolFillShapeButton]:
       self.inDrawingMode = True
       try:
