@@ -16,7 +16,10 @@ namespace vm {
 
 // Arrays are vectors with push and pop functions.
 class array : public mem::vector<item> {
-bool cycle;  
+  bool cycle;  
+
+  void setNonBridgingSlice(size_t l, size_t r, mem::vector<item> *a);
+  void setBridgingSlice(size_t l, size_t r, mem::vector<item> *a);
 public:
   array() {}
   
@@ -24,6 +27,8 @@ public:
     : mem::vector<item>(n), cycle(false)
   {}
 
+  array(size_t n, item i, Int depth);
+
   void push(item i)
   {
     push_back(i);
@@ -42,6 +47,9 @@ public:
     return get<T>((*this)[i]);
   }
   
+  array *slice(Int left, Int right);
+  void setSlice(Int left, Int right, array *a);
+
   void cyclic(bool b) {
     cycle=b;
   }
@@ -49,6 +57,8 @@ public:
   bool cyclic() const {
     return cycle;
   }
+
+  array *copyToDepth(Int depth);
 };
 
 template <typename T>
@@ -69,16 +79,28 @@ inline size_t checkArray(vm::array *a)
   return a->size();
 }
 
-extern const char *arraymismatch;
+extern const void checkequal(size_t i, size_t j);
 
 inline size_t checkArrays(vm::array *a, vm::array *b) 
 {
   size_t asize=checkArray(a);
-  if(asize != checkArray(b))
-    vm::error(arraymismatch);
+  size_t bsize=checkArray(b);
+  checkequal(asize,bsize);
   return asize;
 }
  
+// Tests if an item is actually an array.  This needs to be defined here,
+// after the array type is declared.
+inline bool isarray(const item& it)
+{
+  return *it.kind == typeid(array);
+} 
+
+// Copies an item to a depth d.  If d==0 or if the item is not array, then the
+// item is just returned without copying, otherwise, the array and its
+// subarrays are copied as deeply as possible up to a depth d.
+item copyItemToDepth(item i, Int depth);
+
 } // namespace vm
 
 #endif // ARRAY_H
