@@ -12,16 +12,17 @@
 #define CAMPERROR_H
 
 #include <iostream>
-#include <string>
+
+#include "common.h"
 
 namespace camp {
 
 // Used internally to report an error in an operation.
-void reportError(const std::string& desc);
-void reportError(const std::ostringstream& desc);
+void reportError(const string& desc);
+void reportError(const ostringstream& desc);
   
-void reportWarning(const std::string& desc);
-void reportWarning(const std::ostringstream& desc);
+void reportWarning(const string& desc);
+void reportWarning(const ostringstream& desc);
   
 inline std::ostream& newl(std::ostream& s) {s << '\n'; return s;}
 
