@@ -47,14 +47,18 @@ void stringCast(vm::stack *s)
 template<class T>
 void castString(vm::stack *s)
 {
-  try {
-    string *S=pop<string*>(s);
-    if(S->empty()) {
-      T x=0;
-      s->push(x);
-    } else s->push(lexical::cast<T>(*S));
-  } catch (lexical::bad_cast&) {
-    vm::error("invalid cast.");
+  string *S=pop<string*>(s);
+  if(S->empty()) {
+    T x=0;
+    s->push(x);
+  } else {
+    try {
+      s->push(lexical::cast<T>(*S));
+    } catch (lexical::bad_cast&) {
+      ostringstream buf;
+      buf << "invalid cast from string \"" << *S << "\"";
+      vm::error(buf);
+    }
   }
 }
 
