@@ -15,13 +15,13 @@
 namespace camp {
 
 class drawClipBegin : public drawSuperPathPenBase {
-bool gsave;
+  bool gsave;
 public:
   void noncyclic() {
       reportError("cannot clip to non-cyclic path");
   }
   
-  drawClipBegin(vm::array *src, pen pentype, bool gsave=true)
+  drawClipBegin(const vm::array& src, pen pentype, bool gsave=true)
     : drawSuperPathPenBase(src,pentype), gsave(gsave) {
     for(size_t i=0; i < size; i++)
       if(!cyclic()) noncyclic();
@@ -39,6 +39,10 @@ public:
 
   bool begingroup() {return true;}
   
+  void save(bool b) {
+    gsave=b;
+  }
+  
   bool draw(psfile *out) {
     if(gsave) out->gsave();
     if(empty()) return true;
@@ -48,10 +52,18 @@ public:
     return true;
   }
 
-  bool write(texfile *out) {
+  bool write(texfile *out, const bbox& bpath) {
     if(gsave) out->gsave();
     if(empty()) return true;
     
+    out->verbatim("\\begin{picture}(");
+    double width=bpath.right-bpath.left;
+    double height=bpath.top-bpath.bottom;
+    out->write(width*ps2tex);
+    out->verbatim(",");
+    out->write(height*ps2tex);
+    out->verbatimline(")%");
+
     out->beginspecial();
     out->beginraw();
     writeshiftedpath(out);
