@@ -8,18 +8,22 @@
 #ifndef DRAWCLIPEND_H
 #define DRAWCLIPEND_H
 
-#include "drawelement.h"
+#include "drawclipbegin.h"
 #include "path.h"
 
 namespace camp {
 
 class drawClipEnd : public drawElement {
-bool grestore;  
+  bool grestore;  
+  drawClipBegin *partner;
 public:
-  drawClipEnd(bool grestore=true) : grestore(grestore) {}
+  drawClipEnd(bool grestore=true, drawClipBegin *partner=NULL) : 
+    grestore(grestore), partner(partner) {}
 
   virtual ~drawClipEnd() {}
 
+  bool endclip() {return true;}
+  
   void bounds(bbox& b, iopipestream&, boxvector&, bboxlist& bboxstack) {
     if(bboxstack.size() < 2) {
       reportError("endclip without matching beginclip");
@@ -32,12 +36,22 @@ public:
 
   bool endgroup() {return true;}
   
+  void save(bool b) {
+    grestore=b;
+    if(partner) partner->save(b);
+  }
+  
   bool draw(psfile *out) {
     if(grestore) out->grestore();
     return true;
   }
 
-  bool write(texfile *out) {
+  bool write(texfile *out, const bbox& bpath) {
+    out->verbatimline("\\end{picture}%");
+    out->verbatim("\\kern");
+    double width=bpath.right-bpath.left;
+    out->write(-width*ps2tex);
+    out->verbatimline("pt%");
     if(grestore) out->grestore();
     return true;
   }
@@ -46,4 +60,6 @@ public:
 
 }
 
+GC_DECLARE_PTRFREE(camp::drawClipEnd);
+
 #endif
