@@ -70,8 +70,11 @@ void drawPath::adjustdash(pen& pen0)
       }
     }
     
+    factor=max(factor,0.1);
+    
     ostringstream buf;
-    for(unsigned int i=0; i < n; i++)
+    buf.setf(std::ios::fixed);
+    for(unsigned i=0; i < n; i++)
       buf << pat[i]*factor << " ";
     pen0.setstroke(buf.str());
     pen0.setoffset(pen0.linetype().offset*factor);
@@ -80,8 +83,7 @@ void drawPath::adjustdash(pen& pen0)
   
 // Account for square or extended pen cap contributions to bounding box.
 void cap(bbox& b, double t, path p, pen pentype) {
-  const transform *pT=pentype.getTransform();  
-  transform T=pT ? *pT : identity();
+  transform T=pentype.getTransform();  
   
   double h=0.5*pentype.width();
   pair v=p.dir(t);
@@ -119,6 +121,9 @@ void cap(bbox& b, double t, path p, pen pentype) {
 
 void drawPath::bounds(bbox& b, iopipestream&, boxvector&, bboxlist&)
 {
+  Int l=p.length();
+  if(l < 0) return;
+  
   bbox penbounds=pentype.bounds();
   
   if(cyclic() || pentype.cap() == 1) {
@@ -128,33 +133,31 @@ void drawPath::bounds(bbox& b, iopipestream&, boxvector&, bboxlist&)
   
   b += p.internalbounds(penbounds);
   
-  int l=p.length();
-  if(l < 0) return;
-  
   cap(b,0,p,pentype);
   cap(b,l,p,pentype);
 }
 
 bool drawPath::draw(psfile *out)
 {
-  int n = p.size();
+  Int n = p.size();
   if (n == 0 || pentype.invisible() || pentype.width() == 0.0)
     return true;
 
   pen pen0=pentype;
   adjustdash(pen0);
-  out->setpen(pen0);
 
-  penStart(out);
+  penSave(out);
   penTranslate(out);
 
   out->write(p);
 
   penConcat(out);
 
+  out->setpen(pen0);
+  
   out->stroke();
 
-  penEnd(out);
+  penRestore(out);
 
   return true;
 }
