@@ -147,16 +147,7 @@ types::ty *fieldExp::getObject(coenv& e)
 }
 
 
-void subscriptExp::prettyprint(ostream &out, Int indent)
-{
-  prettyindent(out, indent);
-  out << "subscriptExp\n";
-
-  set->prettyprint(out, indent+1);
-  index->prettyprint(out, indent+1);
-}
-
-array *subscriptExp::getArrayType(coenv &e)
+array *arrayExp::getArrayType(coenv &e)
 {
   types::ty *a = set->cgetType(e);
   if (a->kind == ty_overloaded) {
@@ -175,7 +166,7 @@ array *subscriptExp::getArrayType(coenv &e)
   }
 }
 
-array *subscriptExp::transArray(coenv &e)
+array *arrayExp::transArray(coenv &e)
 {
   types::ty *a = set->cgetType(e);
   if (a->kind == ty_overloaded) {
@@ -210,6 +201,16 @@ bool isAnArray(coenv &e, exp *x)
   return t && t->kind==ty_array;
 }
 
+
+void subscriptExp::prettyprint(ostream &out, Int indent)
+{
+  prettyindent(out, indent);
+  out << "subscriptExp\n";
+
+  set->prettyprint(out, indent+1);
+  index->prettyprint(out, indent+1);
+}
+
 types::ty *subscriptExp::trans(coenv &e)
 {
   array *a = transArray(e);
@@ -249,6 +250,72 @@ void subscriptExp::transWrite(coenv &e, types::ty *t)
 }
 
 
+void slice::prettyprint(ostream &out, Int indent)
+{
+  prettyname(out, "slice", indent);
+  if (left)
+    left->prettyprint(out, indent+1);
+  else
+    prettyname(out, "left omitted", indent+1);
+  if (right)
+    right->prettyprint(out, indent+1);
+  else
+    prettyname(out, "right omitted", indent+1);
+}
+
+void slice::trans(coenv &e)
+{
+  if (left)
+    left->transToType(e, types::primInt());
+  else
+    // If the left index is omitted it can be assumed to be zero.
+    e.c.encode(inst::intpush, (Int)0);
+
+  if (right)
+    right->transToType(e, types::primInt());
+}
+
+
+void sliceExp::prettyprint(ostream &out, Int indent)
+{
+  prettyname(out, "sliceExp", indent);
+  set->prettyprint(out, indent+1);
+  index->prettyprint(out, indent+1);
+}
+
+types::ty *sliceExp::trans(coenv &e)
+{
+  array *a = transArray(e);
+  if (!a)
+    return primError();
+
+  index->trans(e);
+
+  e.c.encode(inst::builtin, index->getRight() ? run::arraySliceRead :
+                                                run::arraySliceReadToEnd);
+
+  return a;
+}
+
+types::ty *sliceExp::getType(coenv &e)
+{
+  array *a = getArrayType(e);
+  return a ? a : primError();
+}
+
+void sliceExp::transWrite(coenv &e, types::ty *t)
+{
+  array *a = transArray(e);
+  if (!a)
+    return;
+  assert(equivalent(a, t));
+
+  index->trans(e);
+
+  e.c.encode(inst::builtin, index->getRight() ? run::arraySliceWrite :
+                                                run::arraySliceWriteToEnd);
+}
+
 void thisExp::prettyprint(ostream &out, Int indent)
 {
   prettyname(out, "thisExp", indent);
@@ -444,6 +511,7 @@ void argument::assignAmbiguity(coenv &e) {
   }
 }
 
+
 void arglist::prettyprint(ostream &out, Int indent)
 {
   prettyname(out, "arglist",indent);
@@ -452,73 +520,6 @@ void arglist::prettyprint(ostream &out, Int indent)
     p->prettyprint(out, indent+1);
 }
 
-/*****
-  Global level caching for callExp.
-  Consider the code:
-
-    write(1+2);
-    write(3+4);
-
-  In the first line, callExp has to resolve the overloaded operator+ when given
-  two integer arguments, and then resolve the overloaded write function when
-  given an integer argument.  On the second line, it has to do this all over
-  again, with different arguments, but arguments that yield the same types.
- 
-  The matchCache attempts to mitigate this work by storing which function type
-  was picked when an overloaded function call was resolved.  The matches are
-  indexed by the marker of the callee expression (which uniquely determines the
-  possibly overloaded type of the callee), and the arguments with which it was
-  called.
-
-  For arguments to match, they must not only have the same types, but the same
-  names, if names are specified.  Calls with overloaded arguments are not added
-  to or checked against the cache.
-*****/
-
-struct cachedCall {
-  void *marker;
-  types::signature *args;
-  types::function *match;
-
-  cachedCall()
-    : marker(0), args(0), match(0) {}
-};
-
-// If the cacheSize is too large, too much data is kept live, which slows down
-// the garbage collector.  This seems to be a happy medium.
-const size_t matchCacheSize=53;
-vector<cachedCall> matchCache(matchCacheSize);
-
-size_t hash(void *marker, types::signature *source) {
-  return 5 * (size_t)marker + source->hash();
-}
-
-void clearCachedCalls() {
-  matchCache.clear();
-  matchCache.resize(matchCacheSize);
-}
-
-function *lookupMatch(void *marker, types::signature *source) {
-  assert(marker!=0);
-  size_t h=hash(marker, source);
-  cachedCall &cell=matchCache[h % matchCacheSize];
-  if (cell.marker==marker &&
-      cell.args &&
-      argumentEquivalent(cell.args, source))
-    return cell.match;
-  else
-    return 0;
-}
-
-void addMatch(void *marker, types::signature *source, function *ft) {
-  assert(marker!=0);
-  size_t h=hash(marker, source);
-  cachedCall &cell=matchCache[h % matchCacheSize];
-  cell.marker=marker;
-  cell.args=source;
-  cell.match=ft;
-}
-
 void callExp::prettyprint(ostream &out, Int indent)
 {
   prettyname(out, "callExp",indent);
@@ -598,51 +599,6 @@ application *callExp::resolve(coenv &e, overloaded *o, signature *source,
   }
 }
 
-bool noOverloadedArgs(signature *source) {
-  types::formal_vector &formals=source->formals;
-  for (types::formal_vector::iterator f=formals.begin(); f!=formals.end(); ++f)
-    if (f->t->kind == types::ty_overloaded)
-      return false;
-  formal &rest=source->getRest();
-  if (rest.t && rest.t->kind == types::ty_overloaded)
-    return false;
-  return true;
-}
-  
-application *callExp::resolveWithCache(coenv &e,
-                                       overloaded *o, signature *source,
-                                       bool tacit) {
-  void *marker=callee->getMarker(e);
-  if (marker!=0 && noOverloadedArgs(source)) {
-    //cerr << "looking up cache" << endl;
-    function *ft=lookupMatch(marker, source);
-    if (ft) {
-      application *a=application::match(e.e, ft, source, *args);
-      if (!a) {
-        em.compiler(getPos());
-        em << "match caching is corrupted";
-      }
-      //cerr << "successful cache hit" << endl;
-      return a;
-    }
-    else {
-      // Match it and add it to the cache.
-      application *a=resolve(e, o, source, tacit);
-
-      // Add to cache.
-      if (a) {
-        //cerr << "adding to cache" << endl;
-        addMatch(marker, source, a->getType());
-      }
-
-      return a;
-    }
-  } else {
-    // Can't cache, just do normal resolve.
-    return resolve(e, o, source, tacit);
-  }
-}
-
 void callExp::reportMismatch(symbol *s, function *ft, signature *source)
 {
   const char *separator=ft->getSignature()->getNumFormals() > 1 ? "\n" : " ";
@@ -700,7 +656,7 @@ application *callExp::getApplication(coenv &e)
     } 
     case ty_overloaded:
       //cerr << "resolving overloaded\n";
-      return resolveWithCache(e, (overloaded *)ft, source, false);
+      return resolve(e, (overloaded *)ft, source, false);
     default:
       //cerr << "not a function\n";
       em.error(getPos());
@@ -764,7 +720,7 @@ types::ty *callExp::getType(coenv &e)
     case ty_function:
       return ((function *)ft)->result;
     case ty_overloaded: {
-      application *a=resolveWithCache(e, (overloaded *)ft, source, true);
+      application *a=resolve(e, (overloaded *)ft, source, true);
       if (a) {
         // Cache the application to avoid calling multimatch again later.
         ca=a;
