@@ -50,17 +50,6 @@ public:
     return 0;
   }
 
-  // If two expressions have the same marker, then they are guaranteed to
-  // return the same (possibly overloaded) types.  This is exploited by callExp
-  // when caching the results of resolving overloaded functions. If this returns
-  // 0 then there are no guarantees on the type of the expression.
-  // Marker are currently only implemented for simple variable names, by the
-  // markers provided by venv::getMarker().
-  virtual void *getMarker(coenv &)
-  {
-    return 0;
-  }
-
   // Checks if the expression can be used as the right side of a scale
   // expression.  ie. 3sin(x)
   // If a "non-scalable" expression is scaled a warning is issued.
@@ -204,11 +193,6 @@ public:
     return value->getName();
   }
 
-  void *getMarker(coenv &e)
-  {
-    return value->getMarker(e);
-  }
-
   void transAsType(coenv &e, types::ty *target) {
     value->varTrans(trans::READ, e, target);
     
@@ -344,16 +328,25 @@ public:
   }
 };
 
-class subscriptExp : public exp {
+class arrayExp : public exp {
+protected:
   exp *set;
-  exp *index;
 
   array *getArrayType(coenv &e);
   array *transArray(coenv &e);
 
+public:
+  arrayExp(position pos, exp *set) 
+    : exp(pos), set(set) {}
+};
+
+
+class subscriptExp : public arrayExp {
+  exp *index;
+
 public:
   subscriptExp(position pos, exp *set, exp *index)
-    : exp(pos), set(set), index(index) {}
+    : arrayExp(pos, set), index(index) {}
 
   void prettyprint(ostream &out, Int indent);
 
@@ -368,6 +361,52 @@ public:
   }
 };
 
+class slice : public absyn {
+  exp *left;
+  exp *right;
+
+public:
+  slice(position pos, exp *left, exp *right)
+    : absyn(pos), left(left), right(right) {}
+
+  void prettyprint(ostream &out, Int indent);
+
+  exp *getLeft() { return left; }
+  exp *getRight() { return right; }
+
+  // Translates code to put the left and right expressions on the stack (in that
+  // order).  If left is omitted, zero is pushed on the stack in it's place.  If
+  // right is omitted, nothing is pushed in its place.
+  void trans(coenv &e);
+
+  slice *evaluate(coenv &e) {
+    return new slice(getPos(),
+                     left ? new tempExp(e, left, types::primInt()) : 0,
+                     right ? new tempExp(e, right, types::primInt()) : 0);
+  }
+};
+
+class sliceExp : public arrayExp {
+  slice *index;
+
+public:
+  sliceExp(position pos, exp *set, slice *index)
+    : arrayExp(pos, set), index(index) {}
+
+  void prettyprint(ostream &out, Int indent);
+
+  types::ty *trans(coenv &e);
+  types::ty *getType(coenv &e);
+  void transWrite(coenv &e, types::ty *target);
+
+  exp *evaluate(coenv &e, types::ty *) {
+    return new sliceExp(getPos(),
+                        new tempExp(e, set, getArrayType(e)),
+                        index->evaluate(e));
+  }
+};
+
+
 // The expression "this," that evaluates to the lexically enclosing record.
 class thisExp : public exp {
 public:
