@@ -5,9 +5,7 @@
 #include <sys/wait.h>
 #include <sys/types.h>
 
-#ifdef HAVE_CONFIG_H
-#include "config.h"
-#endif
+#include "common.h"
 
 #ifdef HAVE_LIBSIGSEGV
 #include <sigsegv.h>
@@ -24,14 +22,17 @@
 
 using namespace settings;
 
-
-errorstream *em;
+errorstream em;
 using interact::interactive;
 
+namespace run {
+  void purge();
+}
+  
 #ifdef HAVE_LIBSIGSEGV
 void stackoverflow_handler (int, stackoverflow_context_t)
 {
-  if(em) em->runtime(vm::getPos());
+  em.runtime(vm::getPos());
   cerr << "Stack overflow" << endl;
   abort();
 }
@@ -39,7 +40,7 @@ void stackoverflow_handler (int, stackoverflow_context_t)
 int sigsegv_handler (void *, int emergency)
 {
   if(!emergency) return 0; // Really a stack overflow
-  if(em) em->runtime(vm::getPos());
+  em.runtime(vm::getPos());
   cerr << "Segmentation fault" << endl;
   cerr << "Please report this programming error to" << endl 
        << BUGREPORT << endl;
@@ -61,39 +62,33 @@ void setsignal(RETSIGTYPE (*handler)(int))
 
 void signalHandler(int)
 {
-  if (em) {
-    // Print the position and trust the shell to print an error message.
-    em->runtime(vm::getPos());
-  }
+  // Print the position and trust the shell to print an error message.
+  em.runtime(vm::getPos());
+
   signal(SIGBUS,SIG_DFL);
   signal(SIGFPE,SIG_DFL);
 }
 
 void interruptHandler(int)
 {
-  if(em) em->Interrupt(true);
+  em.Interrupt(true);
 }
 
-void xasyHandler(int)
-{
-  --signalCount;
-}
-
-//bool status=true;
-
 // Run the config file.
 void doConfig(string filename) {
-  string file = locateFile(filename);
-  if(!file.empty()) {
-    bool autoplain=getSetting<bool>("autoplain");
-    bool listvariables=getSetting<bool>("listvariables");
-    if(autoplain) Setting("autoplain")=false; // Turn off for speed.
-    if(listvariables) Setting("listvariables")=false;
+  if(!filename.empty()) {
+    string file = locateFile(filename);
+    if(!file.empty()) {
+      bool autoplain=getSetting<bool>("autoplain");
+      bool listvariables=getSetting<bool>("listvariables");
+      if(autoplain) Setting("autoplain")=false; // Turn off for speed.
+      if(listvariables) Setting("listvariables")=false;
 
-    runFile(file);
+      runFile(file);
 
-    if(autoplain) Setting("autoplain")=true;
-    if(listvariables) Setting("listvariables")=true;
+      if(autoplain) Setting("autoplain")=true;
+      if(listvariables) Setting("listvariables")=true;
+    }
   }
 }
 
@@ -101,45 +96,43 @@ int main(int argc, char *argv[])
 {
   setsignal(signalHandler);
 
-  // NOTE: Change em to not be a pointer.
-  em = new errorstream;
-
   try {
     setOptions(argc,argv);
   } catch(handled_error) {
-    em->statusError();
+    em.statusError();
   }
   
   fpu_trap(trap());
 
-  if(getSetting<bool>("signal") && getSetting<double>("deconstruct") != 0.0)
-    signal(SIGUSR1,xasyHandler);
-    
   if(interactive) {
     signal(SIGINT,interruptHandler);
     processPrompt();
   } else if (getSetting<bool>("listvariables") && numArgs()==0) {
-    doUnrestrictedList();
+    try {
+      doUnrestrictedList();
+    } catch(handled_error) {
+      em.statusError();
+    } 
   } else {
-    for(int ind=0; ind < numArgs() ; ind++) {
-      processFile(string(getArg(ind)));
+    int n=numArgs();
+    if(n == 0) 
+      processFile("-");
+    else
+    for(int ind=0; ind < n; ind++) {
+      processFile(string(getArg(ind)),n > 1);
       try {
-        if(ind < numArgs()-1)
+        if(ind < n-1)
           setOptions(argc,argv);
       } catch(handled_error) {
-        em->statusError();
+        em.statusError();
       } 
     }
   }
 
-#ifdef USEGC
-  GC_gcollect();
-#endif
-
   if(getSetting<bool>("wait")) {
     int status;
     while(wait(&status) > 0);
   }
   
-  return em->processStatus() ? 0 : 1;
+  return em.processStatus() || interact::interactive ? 0 : 1;
 }
