@@ -15,7 +15,6 @@
 #define PAIR_H
 
 #include <cassert>
-#include <iostream>
 #include <cmath>
 
 #include "common.h"
@@ -23,10 +22,6 @@
 
 namespace camp {
 
-using std::ostream;
-using std::istream;
-using std::ws;
-
 class pair : public gc {
   double x;
   double y;
@@ -159,6 +154,20 @@ public:
     return pair(z.x,-z.y);
   }
   
+// Return the principal branch of the square root (non-negative real part).
+  friend pair Sqrt(const pair& z) {
+    double mag=z.length();
+    if(mag == 0.0) return pair(0.0,0.0);
+    else if(z.x > 0) {
+      double re=sqrt(0.5*(mag+z.x));
+      return pair(re,0.5*z.y/re);
+    } else {
+      double im=sqrt(0.5*(mag-z.x));
+      if(z.y < 0) im=-im;
+      return pair(0.5*z.y/im,im);
+    }
+  }
+
   bool nonZero() const
   {
     return x != 0.0 || y != 0.0;
@@ -167,14 +176,14 @@ public:
   friend istream& operator >> (istream& s, pair& z)
   {
     char c;
-    s >> ws;
+    s >> std::ws;
     bool paren=s.peek() == '('; // parenthesis are optional
     if(paren) s >> c;
-    s >> z.x >> ws;
+    s >> z.x >> std::ws;
     if(!s.eof() && s.peek() == ',') s >> c >> z.y;
     else z.y=0.0;
     if(paren) {
-      s >> ws;
+      s >> std::ws;
       if(s.peek() == ')') s >> c;
     }
     
@@ -210,4 +219,6 @@ inline pair pow(const pair& z, const pair& w)
 
 } //namespace camp
 
+GC_DECLARE_PTRFREE(camp::pair);
+
 #endif
