@@ -14,7 +14,8 @@ namespace parser {
 
 // Opens and parses the file returning the abstract syntax tree.  If
 // there is an unrecoverable parse error, returns null.
-absyntax::file *parseFile(const string& filename, const char *text=NULL);
+absyntax::file *parseFile(const string& filename,
+                          const char *nameOfAction);
 
 // Parses string and returns the abstract syntax tree.  Any error in lexing or
 // parsing will be reported and a handled_error thrown.  If the string is
