@@ -544,14 +544,14 @@ bbox path::internalbounds(const bbox& padding) const
     pair post=postcontrol(i)-point(i);
     
     // Check node x coordinate
-    if(pre.getx() >= 0.0 ^ post.getx() >= 0) {
+    if((pre.getx() >= 0.0) ^ (post.getx() >= 0)) {
       pair z=point(i);
       box += z+padding.left;
       box += z+padding.right;
     }
 			      
     // Check node y coordinate
-    if(pre.gety() >= 0.0 ^ post.gety() >= 0) {
+    if((pre.gety() >= 0.0) ^ (post.gety() >= 0)) {
       pair z=point(i);
       box += z+pair(0,padding.bottom);
       box += z+pair(0,padding.top);
@@ -941,8 +941,6 @@ void intersections(std::vector<double>& S, std::vector<double>& T,
 
 ostream& operator<< (ostream& out, const path& p)
 {
-  size_t oldPrec = out.precision(6);
-  
   Int n = p.n;
   switch(n) {
   case 0:
@@ -975,8 +973,6 @@ ostream& operator<< (ostream& out, const path& p)
     break;
   }
 
-  out.precision(oldPrec);
-
   return out;
 }
 
@@ -988,8 +984,6 @@ path concat(const path& p1, const path& p2)
   if (n2 == -1) return p1;
   pair a=p1.point(n1);
   pair b=p2.point((Int) 0);
-  if ((a-b).abs2() > Fuzz2*max(a.abs2(),b.abs2()))
-    reportError("paths in concatenation do not meet");
 
   mem::vector<solvedKnot> nodes(n1+n2+1);
 
