@@ -154,7 +154,7 @@ void picture::texinit()
   // Output any new texpreamble commands
   if(pd.tex.isopen()) {
     if(pd.TeXpipepreamble.empty()) return;
-    texpreamble(pd.tex,pd.TeXpipepreamble);
+    texpreamble(pd.tex,pd.TeXpipepreamble,false);
     pd.TeXpipepreamble.clear();
     return;
   }
@@ -212,7 +212,7 @@ bool picture::texprocess(const string& texname, const string& outname,
       voffset += paperHeight-height-b.bottom-bboxshift.gety();
     
       ostringstream dcmd;
-      dcmd << "'" << getSetting<string>("dvips") << "' -R -Pdownload35"
+      dcmd << "'" << getSetting<string>("dvips") << "' -R -Pdownload35 -D600"
 	   << " -O " << hoffset << "bp," << voffset << "bp"
 	   << " -T " << paperWidth << "bp," << paperHeight << "bp "
            << getSetting<string>("dvipsOptions");
@@ -292,7 +292,7 @@ bool picture::postprocess(const string& prename, const string& outname,
 {
   int status=0;
   
-  if((pdf && Labels) || !(epsformat || xobject)) {
+  if((pdf && Labels) || !epsformat) {
     if(pdfformat) {
       if(pdf && Labels) status=rename(prename.c_str(),outname.c_str());
       else status=epstopdf(prename,outname);
@@ -311,7 +311,7 @@ bool picture::postprocess(const string& prename, const string& outname,
   }
   if(status != 0) return false;
   
-  if(verbose > (xobject ? 1 : 0)) 
+  if(verbose > 0)
     cout << "Wrote " << outname << endl;
   if(settings::view() && view) {
     if(epsformat || pdfformat) {
@@ -351,6 +351,14 @@ bool picture::postprocess(const string& prename, const string& outname,
   return true;
 }
 
+string Outname(const string& prefix, const string& outputformat,
+	       bool standardout)
+{
+  return (standardout ? "-" : buildname(prefix,outputformat,"",
+					prefix != settings::outname() &&
+					!globalwrite()));
+}
+
 bool picture::shipout(picture *preamble, const string& Prefix,
 		      const string& format, double magnification,
 		      bool wait, bool view)
@@ -370,9 +378,7 @@ bool picture::shipout(picture *preamble, const string& Prefix,
   epsformat=outputformat == "eps";
   pdfformat=outputformat == "pdf";
   xobject=magnification > 0;
-  string outname=(standardout ? "-" : buildname(prefix,outputformat,"",
-				   prefix != settings::outname() &&
-				   !globalwrite()));
+  string outname=Outname(prefix,outputformat,standardout);
   string epsname=epsformat ? (standardout ? "" : outname) :
     auxname(prefix,"eps");
   string prename=((epsformat && !pdf) || !Labels) ? epsname : 
@@ -389,7 +395,8 @@ bool picture::shipout(picture *preamble, const string& Prefix,
     return postprocess(epsname,outname,outputformat,1.0,wait,view);
   }
   
-  if(xobject && getSetting<string>("xformat") == "png") {
+  bool pngxformat=xobject && getSetting<string>("xformat") == "png";
+  if(pngxformat) {
     // Work around half-pixel bounding box bug in Ghostscript pngalpha driver
     double fuzz=0.5/magnification;
     b.top += fuzz;
@@ -436,6 +443,8 @@ bool picture::shipout(picture *preamble, const string& Prefix,
   
   bbox bshift=b;
   
+  transparency=false;
+  
   while(p != nodes.end()) {
     string psname,pdfname;
     if(Labels) {
@@ -484,6 +493,9 @@ bool picture::shipout(picture *preamble, const string& Prefix,
     out.epilogue();
     out.close();
     
+    if(out.Transparency())
+      transparency=true;
+    
     if(Labels) {
       tex->resetpen();
       if(status) {
@@ -524,9 +536,14 @@ bool picture::shipout(picture *preamble, const string& Prefix,
 	    unlink(p->c_str());
 	}
       }
-      if(status)
-	status=postprocess(prename,outname,outputformat,magnification,wait,
-			   view);
+      if(status) {
+	if(xobject) {
+	  if(transparency && pngxformat)
+	    status=(epstopdf(prename,Outname(prefix,"pdf",standardout)) == 0);
+	} else
+	  status=postprocess(prename,outname,outputformat,magnification,wait,
+			     view);
+      }
     }
   }
   
