@@ -13,6 +13,7 @@
 #include <cfloat>
 #include <locale.h>
 #include <unistd.h>
+#include <algorithm>
 
 #include "common.h"
 
@@ -1065,7 +1066,7 @@ string outname() {
 
 void initDir() {
   initdir=Getenv(HOME,msdos)+"/."+suffix;
-  mkdir(initdir.c_str(),0xFFFF);
+  mkdir(initdir.c_str(),0777);
 }
   
 void setPath() {
@@ -1094,7 +1095,7 @@ void SetPageDimensions() {
      getSetting<double>("paperheight") != 0.0) return;
   
   const double inches=72;
-  const double cm=inches/2.540005;
+  const double cm=inches/2.54;
   
   if(paperType == "letter") {
     Setting("paperwidth")=8.5*inches;
