@@ -33,7 +33,7 @@ namespace vm {
 mem::list<bpinfo> bplist;
   
 namespace {
-position curPos = position::nullPos();
+position curPos = nullPos;
 const program::label nulllabel;
 }
 
@@ -88,7 +88,7 @@ void stack::breakpoint(absyntax::runnable *r)
 void stack::debug() 
 {
   if(!curPos) return;
-  if(indebugger) {em->clear(); return;}
+  if(indebugger) {em.clear(); return;}
   
   switch(debugOp) {
   case 'i': // inst
@@ -145,7 +145,7 @@ void stack::run(program *code, vars_t vars)
       cerr << "\n";
 #endif
 
-      if(settings::verbose > 4) em->trace(curPos);
+      if(settings::verbose > 4) em.trace(curPos);
       
       if(!bplist.empty()) debug();
       
@@ -163,18 +163,18 @@ void stack::run(program *code, vars_t vars)
             break;
         
           case inst::varpush:
-            push((*vars)[get<int>(i)]);
+            push((*vars)[get<Int>(i)]);
             break;
 
           case inst::varsave:
-            (*vars)[get<int>(i)] = top();
+            (*vars)[get<Int>(i)] = top();
             break;
         
           case inst::fieldpush: {
             vars_t frame = pop<vars_t>();
             if (!frame)
 	      error("dereference of null pointer");
-            push((*frame)[get<int>(i)]);
+            push((*frame)[get<Int>(i)]);
             break;
           }
         
@@ -182,7 +182,7 @@ void stack::run(program *code, vars_t vars)
             vars_t frame = pop<vars_t>();
             if (!frame)
 	      error("dereference of null pointer");
-            (*frame)[get<int>(i)] = top();
+            (*frame)[get<Int>(i)] = top();
             break;
           }
 	
@@ -229,7 +229,7 @@ void stack::run(program *code, vars_t vars)
           }
 
           case inst::alloc: {
-            vars->extend(get<int>(i));
+            vars->extend(get<Int>(i));
             break;
           }
 
@@ -343,9 +343,9 @@ position getPos() {
 
 void errornothrow(const char* message)
 {
-  em->error(curPos);
-  *em << message;
-  em->sync();
+  em.error(curPos);
+  em << message;
+  em.sync();
 }
   
 void error(const char* message)
