@@ -9,13 +9,15 @@
 #include <cstdio>
 #include "symbol.h"
 
+
+
 namespace sym {
 
 GCInit symbol::initialize;
-mem::map<CONST mem::string,symbol> symbol::dict;
-symbol *symbol::initsym=symbol::specialTrans(mem::string("operator init"));
-symbol *symbol::castsym=symbol::specialTrans(mem::string("operator cast"));
-symbol *symbol::ecastsym=symbol::specialTrans(mem::string("operator ecast"));
+mem::map<CONST string,symbol> symbol::dict;
+symbol *symbol::initsym=symbol::specialTrans(string("operator init"));
+symbol *symbol::castsym=symbol::specialTrans(string("operator cast"));
+symbol *symbol::ecastsym=symbol::specialTrans(string("operator ecast"));
 
 } // namespace sym
 
